====================
Tables of transforms
====================

.. _table_fourier_transforms:

Fourier Transforms
==================

Lcapy can compute many Fourier transforms including:

.. include:: fourier_transforms.rst


.. _table_discrete_time_fourier_transforms:

Discrete-Time Fourier Transforms (DTFT)
=======================================

Lcapy can compute many discrete-time Fourier transforms including:

.. include:: DTFTs.rst

Note, :math:`N_e` is even and :math:`N_o` is odd.             


Discrete-Time Fourier Transforms (DTFT) (normalized angular frequency)
======================================================================

Lcapy can compute many discrete-time Fourier transforms in the
:math:`\Omega` form, including:

.. include:: ODTFTs.rst

Note, :math:`N_e` is even and :math:`N_o` is odd.             

             
.. _table_discrete_fourier_transforms:

Discrete Fourier Transforms (DFT)
=================================

Lcapy can compute some discrete Fourier transforms including:

.. include:: DFTs.rst             

             
.. _table_laplace_transforms:

Laplace Transforms
==================

Lcapy can compute many Laplace transforms including:

.. include:: laplace_transforms.rst

             
.. _table_z_transforms:

Z Transforms
============

Lcapy can compute many Z transforms including:

.. include:: ztransforms.rst
             
